@@ -1,4 +1,5 @@
+#' @importFrom precrec
+
 library(testthat)
-library(precrec)
 
 test_check("precrec")
